@@ -13,6 +13,9 @@
 
 #include <boost/interprocess/detail/config_begin.hpp>
 #include <boost/interprocess/detail/workaround.hpp>
+#include <boost/interprocess/errors.hpp>
+#include <boost/interprocess/permissions.hpp>
+
 #include <string>
 
 #if (defined BOOST_INTERPROCESS_WINDOWS)
@@ -52,6 +55,7 @@ typedef struct mapping_handle_impl_t{
 typedef enum { read_only      = winapi::generic_read
              , read_write     = winapi::generic_read | winapi::generic_write
              , copy_on_write
+             , read_private
              , invalid_mode   = 0xffff 
              } mode_t;
 
@@ -82,34 +86,36 @@ inline file_handle_t file_handle_from_mapping_handle(mapping_handle_t hnd)
 {  return hnd.handle; }
 
 inline bool create_directory(const char *path)
-{  return winapi::create_directory(path, 0); }
+{  return winapi::create_directory(path); }
 
 inline const char *get_temporary_path()
 {  return std::getenv("TMP"); }
 
 
 inline file_handle_t create_new_file
-   (const char *name, mode_t mode = read_write, bool temporary = false)
+   (const char *name, mode_t mode, const permissions & perm, bool temporary = false)
 {  
    unsigned long attr = temporary ? winapi::file_attribute_temporary : 0;
    return winapi::create_file
-      (name, (unsigned int)mode, winapi::create_new, attr);  
+      ( name, (unsigned int)mode, winapi::create_new, attr
+      , (winapi::interprocess_security_attributes*)perm.get_permissions());  
 }
 
 inline file_handle_t create_or_open_file
-   (const char *name, mode_t mode = read_write, bool temporary = false)
+   (const char *name, mode_t mode, const permissions & perm, bool temporary = false)
 {  
    unsigned long attr = temporary ? winapi::file_attribute_temporary : 0;
    return winapi::create_file
-      (name, (unsigned int)mode, winapi::open_always, attr);  
+      ( name, (unsigned int)mode, winapi::open_always, attr
+      , (winapi::interprocess_security_attributes*)perm.get_permissions());  
 }
 
 inline file_handle_t open_existing_file
-   (const char *name, mode_t mode = read_write, bool temporary = false)
+   (const char *name, mode_t mode, bool temporary = false)
 {  
    unsigned long attr = temporary ? winapi::file_attribute_temporary : 0;
    return winapi::create_file
-      (name, (unsigned int)mode, winapi::open_existing, attr);  
+      (name, (unsigned int)mode, winapi::open_existing, attr, 0);  
 }
 
 inline bool delete_file(const char *name)
@@ -121,7 +127,7 @@ inline bool truncate_file (file_handle_t hnd, std::size_t size)
    if(!winapi::get_file_size(hnd, filesize))
       return false;
 
-   if(size > filesize){
+   if(size > (unsigned long long)filesize){
       if(!winapi::set_file_pointer_ex(hnd, filesize, 0, winapi::file_begin)){
          return false;
       }      
@@ -262,8 +268,7 @@ inline bool delete_subdirectories_recursive
                //if(::SetFileAttributes(strFilePath.c_str(), winapi::file_attribute_normal) == 0)
                //return winapi::get_last_error();
                // Delete file
-               if(winapi::delete_file(strFilePath.c_str()) == 0)
-                  return false;
+               winapi::delete_file(strFilePath.c_str());
             }
          }
       //Go to the next file
@@ -299,6 +304,44 @@ inline bool delete_subdirectories(const std::string &refcstrRootDirectory, const
    return delete_subdirectories_recursive(refcstrRootDirectory, dont_delete_this, 0u);
 }
 
+
+template<class Function>
+inline bool for_each_file_in_dir(const char *dir, Function f)
+{
+   void *             hFile;                       // Handle to directory
+   winapi::win32_find_data_t  FileInformation;     // File information
+
+   //Get base directory
+   std::string str(dir);
+   const std::size_t base_root_dir_len = str.size();
+
+   //Find all files and directories
+   str  +=  "\\*.*";
+   hFile = winapi::find_first_file(str.c_str(), &FileInformation);
+   if(hFile != winapi::invalid_handle_value){
+      do{   //Now loop every file
+         str.erase(base_root_dir_len);
+         //If it's not "." or ".." skip it
+         if(FileInformation.cFileName[0] != '.'){
+            str += "\\";   str += FileInformation.cFileName;
+            //If it's a file, apply erase logic
+            if(!(FileInformation.dwFileAttributes & winapi::file_attribute_directory)){
+               f(str.c_str(), FileInformation.cFileName);
+            }
+         }
+      //Go to the next file
+      } while(winapi::find_next_file(hFile, &FileInformation) == 1);
+
+      // Close handle and see if the loop has ended with an error
+      winapi::find_close(hFile);
+      if(winapi::get_last_error() != winapi::error_no_more_files){
+         return false;
+      }
+   }
+   return true;
+}
+
+
 #else    //#if (defined BOOST_INTERPROCESS_WINDOWS)
 
 typedef int       file_handle_t;
@@ -313,6 +356,7 @@ typedef struct mapping_handle_impl_t
 typedef enum { read_only      = O_RDONLY
              , read_write     = O_RDWR
              , copy_on_write
+             , read_private
              , invalid_mode   = 0xffff 
              } mode_t;
 
@@ -335,7 +379,7 @@ inline file_handle_t file_handle_from_mapping_handle(mapping_handle_t hnd)
 {  return hnd.handle; }
 
 inline bool create_directory(const char *path)
-{  return ::mkdir(path, S_IRWXU | S_IRWXG | S_IROTH | S_IXOTH) == 0; }
+{  return ::mkdir(path, 0777) == 0 && ::chmod(path, 0777) == 0; }
 
 inline const char *get_temporary_path()
 {
@@ -351,24 +395,32 @@ inline const char *get_temporary_path()
 }
 
 inline file_handle_t create_new_file
-   (const char *name, mode_t mode = read_write, bool temporary = false)
+   (const char *name, mode_t mode, const permissions & perm, bool temporary = false)
 {  
    (void)temporary;
-   return ::open(name, ((int)mode) | O_EXCL | O_CREAT, S_IRWXG | S_IRWXO | S_IRWXU); 
+   int ret = ::open(name, ((int)mode) | O_EXCL | O_CREAT, perm.get_permissions());
+   if(ret >= 0){
+      ::fchmod(ret, perm.get_permissions());
+   }
+   return ret;
 }
 
 inline file_handle_t create_or_open_file
-   (const char *name, mode_t mode = read_write, bool temporary = false)
+   (const char *name, mode_t mode, const permissions & perm, bool temporary = false)
 {  
    (void)temporary;
-   return ::open(name, ((int)mode) | O_CREAT, S_IRWXG | S_IRWXO | S_IRWXU); 
+   int ret = ::open(name, ((int)mode) | O_CREAT, perm.get_permissions());
+   if(ret >= 0){
+      ::fchmod(ret, perm.get_permissions());
+   }
+   return ret;
 }
 
 inline file_handle_t open_existing_file
-   (const char *name, mode_t mode = read_write, bool temporary = false)
+   (const char *name, mode_t mode, bool temporary = false)
 {  
    (void)temporary;
-   return ::open(name, (int)mode, S_IRWXG | S_IRWXO | S_IRWXU); 
+   return ::open(name, (int)mode, 0666);
 }
 
 inline bool delete_file(const char *name)
@@ -388,7 +440,7 @@ inline bool get_file_size(file_handle_t hnd, offset_t &size)
 }
 
 inline bool set_file_pointer(file_handle_t hnd, offset_t off, file_pos_t pos)
-{  return off == ::lseek(hnd, off, (int)pos); }
+{  return ((off_t)(-1)) != ::lseek(hnd, off, (int)pos); }
 
 inline bool get_file_pointer(file_handle_t hnd, offset_t &off)
 {  
@@ -543,6 +595,48 @@ inline bool delete_subdirectories_recursive
    return std::remove(refcstrRootDirectory.c_str()) ? false : true;
 }
 
+template<class Function>
+inline bool for_each_file_in_dir(const char *dir, Function f)
+{
+   std::string refcstrRootDirectory(dir);
+
+   DIR *d = opendir(refcstrRootDirectory.c_str());
+   if(!d) {
+      return false;
+   }
+
+   struct dir_close
+   {
+      DIR *d_;
+      dir_close(DIR *d) : d_(d) {}
+      ~dir_close() { ::closedir(d_); }
+   } dc(d); (void)dc;
+
+   struct ::dirent *de;
+   struct ::stat st;
+   std::string fn;
+
+   while((de=::readdir(d))) {
+      if( de->d_name[0] == '.' && ( de->d_name[1] == '\0'
+            || (de->d_name[1] == '.' && de->d_name[2] == '\0' )) ){
+         continue;
+      }
+      fn = refcstrRootDirectory;
+      fn += '/';
+      fn += de->d_name;
+
+      if(::stat(fn.c_str(), & st)) {
+         return false;
+      }
+      //If it's a file, apply erase logic
+      if(!S_ISDIR(st.st_mode)) {
+         f(fn.c_str(), de->d_name);
+      }
+   }
+   return true;
+}
+
+
 //This function erases all the subdirectories of a directory except the one pointed by "dont_delete_this"
 inline bool delete_subdirectories(const std::string &refcstrRootDirectory, const char *dont_delete_this)
 {
@@ -551,6 +645,19 @@ inline bool delete_subdirectories(const std::string &refcstrRootDirectory, const
 
 #endif   //#if (defined BOOST_INTERPROCESS_WINDOWS)
 
+inline bool open_or_create_directory(const char *dir_name)
+{
+   //If fails, check that it's because it already exists
+   if(!create_directory(dir_name)){
+      error_info info(system_error_code());
+      if(info.get_error_code() != already_exists_error){
+         return false;
+      }
+   }
+   return true;
+}
+
+
 }  //namespace detail{
 }  //namespace interprocess {
 }  //namespace boost {
