@@ -11,7 +11,10 @@
 #pragma once
 #endif
 
+#include <boost/spirit/home/qi/directive/encoding.hpp>
+#include <boost/spirit/home/qi/directive/hold.hpp>
 #include <boost/spirit/home/qi/directive/lexeme.hpp>
+#include <boost/spirit/home/qi/directive/no_skip.hpp>
 #include <boost/spirit/home/qi/directive/matches.hpp>
 #include <boost/spirit/home/qi/directive/no_case.hpp>
 #include <boost/spirit/home/qi/directive/omit.hpp>
