@@ -11,7 +11,7 @@
 #include <boost/math/special_functions/asinh.hpp>
 #include "c_policy.hpp"
 
-extern "C" float BOOST_MATH_TR1_DECL asinhf BOOST_PREVENT_MACRO_SUBSTITUTION(float x)
+extern "C" float BOOST_MATH_TR1_DECL asinhf BOOST_PREVENT_MACRO_SUBSTITUTION(float x) BOOST_MATH_C99_THROW_SPEC
 {
    return c_policies::asinh BOOST_PREVENT_MACRO_SUBSTITUTION(x);
 }
