@@ -29,6 +29,8 @@ namespace std{
 #include <boost/serialization/tracking.hpp>
 
 #define BOOST_ARCHIVE_SOURCE
+// include this to prevent linker errors when the
+// same modules are marked export and import.
 #define BOOST_SERIALIZATION_SOURCE
 
 #include <boost/archive/archive_exception.hpp>
@@ -49,7 +51,7 @@ namespace detail {
 
 class basic_iarchive_impl {
     friend class basic_iarchive;
-    version_type m_archive_library_version;
+    library_version_type m_archive_library_version;
     unsigned int m_flags;
 
     //////////////////////////////////////////////////////////////////////
@@ -172,7 +174,7 @@ class basic_iarchive_impl {
         pending_version(0)
     {}
     ~basic_iarchive_impl(){}
-    void set_library_version(version_type archive_library_version){
+    void set_library_version(library_version_type archive_library_version){
         m_archive_library_version = archive_library_version;
     }
     bool
@@ -291,15 +293,8 @@ inline class_id_type
 basic_iarchive_impl::register_type(
     const basic_iserializer & bis
 ){
-    assert(
-        cobject_info_set.size() 
-        <= 
-        boost::integer_traits<class_id_type>::const_max
-    );
-    class_id_type id(static_cast<class_id_type>(
-        cobject_info_set.size()
-    ));
-    cobject_type co(id, bis);
+    class_id_type cid(cobject_info_set.size());
+    cobject_type co(cid, bis);
     std::pair<cobject_info_set_type::const_iterator, bool>
         result = cobject_info_set.insert(co);
 
@@ -307,12 +302,12 @@ basic_iarchive_impl::register_type(
         cobject_id_vector.push_back(cobject_id(bis));
         assert(cobject_info_set.size() == cobject_id_vector.size());
     }
-    id = result.first->m_class_id;
+    cid = result.first->m_class_id;
     // borland complains without this minor hack
-    const int tid = id;
+    const int tid = cid;
     cobject_id & coid = cobject_id_vector[tid];
     coid.bpis_ptr = bis.get_bpis_ptr();
-    return id;
+    return cid;
 }
 
 void
@@ -322,7 +317,7 @@ basic_iarchive_impl::load_preamble(
 ){
     if(! co.initialized){
         if(co.bis_ptr->class_info()){
-            class_id_optional_type cid;
+            class_id_optional_type cid(class_id_type(0));
             load(ar, cid);    // to be thrown away
             load(ar, co.tracking_level);
             load(ar, co.file_version);
@@ -382,7 +377,7 @@ basic_iarchive_impl::load_object(
 
     object_id_type this_id;
     moveable_objects_start =
-    this_id = object_id_vector.size();
+    this_id = object_id_type(object_id_vector.size());
 
     // if we tracked this object when the archive was saved
     if(tracking){ 
@@ -393,7 +388,7 @@ basic_iarchive_impl::load_object(
         // add a new enty into the tracking list
         object_id_vector.push_back(aobject(t, cid));
         // and add an entry for this object
-        moveable_objects_end = object_id_vector.size();
+        moveable_objects_end = object_id_type(object_id_vector.size());
     }
     // read data
     (bis.load_object_data)(ar, t, co.file_version);
@@ -418,11 +413,6 @@ basic_iarchive_impl::load_pointer(
         return bpis_ptr;
     }
 
-    assert(
-        cobject_info_set.size() 
-        <= 
-        boost::integer_traits<class_id_type>::const_max
-    );
     // if its a new class type - i.e. never been registered
     if(class_id_type(cobject_info_set.size()) <= cid){
         // if its either abstract
@@ -527,7 +517,7 @@ basic_iarchive::~basic_iarchive()
 }
 
 BOOST_ARCHIVE_DECL(void)
-basic_iarchive::set_library_version(version_type archive_library_version){
+basic_iarchive::set_library_version(library_version_type archive_library_version){
     pimpl->set_library_version(archive_library_version);
 }
 
@@ -571,7 +561,7 @@ basic_iarchive::delete_created_pointers()
     pimpl->delete_created_pointers();
 }
 
-BOOST_ARCHIVE_DECL(unsigned int) 
+BOOST_ARCHIVE_DECL(boost::archive::library_version_type) 
 basic_iarchive::get_library_version() const{
     return pimpl->m_archive_library_version;
 }
