@@ -6,14 +6,6 @@
 =============================================================================*/
 #include "mini_cb.hpp"
 
-// This is not really called. Its only purpose is to
-// instantiate the constructor of the grammar.
-void instantiate_expression()
-{
-    typedef std::string::const_iterator iterator_type;
-    symbols<char, function_info> functions;
-    symbols<char, int> vars;
-    std::vector<int> code;
-    expression<iterator_type> g(code, vars, functions);
-}
+typedef std::string::const_iterator iterator_type;
+template struct expression<iterator_type>;
 
