@@ -9,6 +9,7 @@
 #include <boost/spirit/include/qi.hpp>
 #include <boost/spirit/include/phoenix_core.hpp>
 #include <boost/spirit/include/phoenix_operator.hpp>
+#include <boost/fusion/include/adapt_struct.hpp>
 #include <iostream>
 #include <string>
 #include <cstdlib>
@@ -280,11 +281,12 @@ namespace boost { namespace spirit { namespace traits
     // in this case we just expose the embedded 'int' as the attribute instance 
     // to use, allowing to leave the function 'post()' empty
     template <>
-    struct transform_attribute<int_data, int>
+    struct transform_attribute<int_data, int, qi::domain>
     {
         typedef int& type;
         static int& pre(int_data& d) { return d.i; }
         static void post(int_data& val, int const& attr) {}
+        static void fail(int_data&) {}
     };
 }}}
 //]
@@ -326,7 +328,7 @@ main()
         test_parser("x", lit('x'));                 // explicit literal
         test_parser("x", char_('x'));               // ascii::char_
         //]
-        
+
         //[reference_char_range
         char ch;
         test_parser_attr("5", char_('0','9'), ch);  // ascii::char_ range
@@ -417,6 +419,23 @@ main()
         //]
     }
     
+    {
+        //[reference_using_declarations_no_skip
+        using boost::spirit::qi::no_skip;
+        using boost::spirit::qi::char_;
+        //]
+        
+        //[reference_no_skip
+        /*`The use of no_skip here will prevent skipping of whitespace in front 
+           and in between the characters of the string `'  abc  '`.*/
+        
+        std::string str;
+        test_phrase_parser_attr("'  abc  '", 
+            '\'' >> no_skip[+~char_('\'')] >> '\'', str); 
+        std::cout << str << std::endl;    // will output: >  abc  <
+        //]
+    }
+    
     {
         //[reference_using_declarations_no_case
         using boost::spirit::ascii::no_case;
@@ -649,7 +668,7 @@ main()
         
         //[reference_eps_while
         /*`This example simulates the "classic" `while_p` parser. Here, the kleene loop
-            will exit once the condition, c, becomes true. Notice that the condition, `c,
+            will exit once the condition, `c`, becomes true. Notice that the condition, `c`,
             is turned to `false` when we get to parse `4`.
          */
         test_phrase_parser("1 2 3 4", 
